==> igniteui-webcomponents-core-4.0.2.tgz: package/esm5/lib/FullStochasticOscillatorIndicatorDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { StrategyBasedIndicatorDescriptionMetadata } from "./StrategyBasedIndicatorDescriptionMetadata";
import { FullStochasticOscillatorIndicatorDescription } from "./FullStochasticOscillatorIndicatorDescription";
/**
 * @hidden
 */
var FullStochasticOscillatorIndicatorDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(FullStochasticOscillatorIndicatorDescriptionMetadata, _super);
    function FullStochasticOscillatorIndicatorDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    FullStochasticOscillatorIndicatorDescriptionMetadata.b = function (a) {
        if (FullStochasticOscillatorIndicatorDescriptionMetadata.a == null) {
            FullStochasticOscillatorIndicatorDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            FullStochasticOscillatorIndicatorDescriptionMetadata.c(FullStochasticOscillatorIndicatorDescriptionMetadata.a);
        }
        if (a.j(FullStochasticOscillatorIndicatorDescriptionMetadata.a)) {
            return;
        }
        a.y(FullStochasticOscillatorIndicatorDescriptionMetadata.a);
    };
    FullStochasticOscillatorIndicatorDescriptionMetadata.c = function (a) {
        StrategyBasedIndicatorDescriptionMetadata.c(a);
        a.item("Period", "Number:int");
        a.item("SmoothingPeriod", "Number:int");
        a.item("TriggerPeriod", "Number:int");
    };
    FullStochasticOscillatorIndicatorDescriptionMetadata.d = function (a) {
        FullStochasticOscillatorIndicatorDescriptionMetadata.b(a);
        a.aa("FullStochasticOscillatorIndicator", function () { return new FullStochasticOscillatorIndicatorDescription(); });
        a.z("FullStochasticOscillatorIndicator", FullStochasticOscillatorIndicatorDescriptionMetadata.a);
    };
    FullStochasticOscillatorIndicatorDescriptionMetadata.$t = markType(FullStochasticOscillatorIndicatorDescriptionMetadata, 'FullStochasticOscillatorIndicatorDescriptionMetadata');
    FullStochasticOscillatorIndicatorDescriptionMetadata.a = null;
    return FullStochasticOscillatorIndicatorDescriptionMetadata;
}(Base));
export { FullStochasticOscillatorIndicatorDescriptionMetadata };

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm5/lib/FullStochasticOscillatorIndicatorDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { StrategyBasedIndicatorDescriptionMetadata } from "./StrategyBasedIndicatorDescriptionMetadata";
import { FullStochasticOscillatorIndicatorDescription } from "./FullStochasticOscillatorIndicatorDescription";
/**
 * @hidden
 */
var FullStochasticOscillatorIndicatorDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(FullStochasticOscillatorIndicatorDescriptionMetadata, _super);
    function FullStochasticOscillatorIndicatorDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    FullStochasticOscillatorIndicatorDescriptionMetadata.b = function (a) {
        if (FullStochasticOscillatorIndicatorDescriptionMetadata.a == null) {
            FullStochasticOscillatorIndicatorDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            FullStochasticOscillatorIndicatorDescriptionMetadata.c(FullStochasticOscillatorIndicatorDescriptionMetadata.a);
        }
        if (a.k(FullStochasticOscillatorIndicatorDescriptionMetadata.a)) {
            return;
        }
        a.aa(FullStochasticOscillatorIndicatorDescriptionMetadata.a);
    };
    FullStochasticOscillatorIndicatorDescriptionMetadata.c = function (a) {
        StrategyBasedIndicatorDescriptionMetadata.c(a);
        a.item("Period", "Number:int");
        a.item("SmoothingPeriod", "Number:int");
        a.item("TriggerPeriod", "Number:int");
    };
    FullStochasticOscillatorIndicatorDescriptionMetadata.d = function (a) {
        FullStochasticOscillatorIndicatorDescriptionMetadata.b(a);
        a.ac("FullStochasticOscillatorIndicator", function () { return new FullStochasticOscillatorIndicatorDescription(); });
        a.ab("FullStochasticOscillatorIndicator", FullStochasticOscillatorIndicatorDescriptionMetadata.a);
    };
    FullStochasticOscillatorIndicatorDescriptionMetadata.$t = markType(FullStochasticOscillatorIndicatorDescriptionMetadata, 'FullStochasticOscillatorIndicatorDescriptionMetadata');
    FullStochasticOscillatorIndicatorDescriptionMetadata.a = null;
    return FullStochasticOscillatorIndicatorDescriptionMetadata;
}(Base));
export { FullStochasticOscillatorIndicatorDescriptionMetadata };
